==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/igr-linear-progress.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { LinearProgressLabelAlign_$type } from "./LinearProgressLabelAlign";
import { IgrProgressBase } from "./igr-progress-base";
import { LinearProgress } from "./LinearProgress";
import { IgcLinearProgressComponent, defineComponents } from "igniteui-webcomponents";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * A linear progress indicator used to express unspecified wait time or display
 * the length of a process.
*/
var IgrLinearProgress = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrLinearProgress, _super);
    function IgrLinearProgress(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcLinearProgressComponent);
        return _this;
    }
    IgrLinearProgress.prototype.createImplementation = function () {
        return new LinearProgress();
    };
    Object.defineProperty(IgrLinearProgress.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrLinearProgress.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrLinearProgress.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-linear-progress", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrLinearProgress.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrLinearProgress.prototype, "striped", {
        /**
         * Sets the striped look of the control.
        */
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            this.i.o = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrLinearProgress.prototype, "labelAlign", {
        /**
         * The position for the default label of the control.
        */
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = ensureEnum(LinearProgressLabelAlign_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrLinearProgress;
}(IgrProgressBase));
export { IgrLinearProgress };

==> igniteui-react-18.6.1-beta.0.tgz: package/esm5/lib/igr-linear-progress.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { LinearProgressLabelAlign_$type } from "./LinearProgressLabelAlign";
import { IgrProgressBase } from "./igr-progress-base";
import { LinearProgress } from "./LinearProgress";
import { IgcLinearProgressComponent, defineComponents } from "igniteui-webcomponents";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * A linear progress indicator used to express unspecified wait time or display
 * the length of a process.
*/
var IgrLinearProgress = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrLinearProgress, _super);
    function IgrLinearProgress(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcLinearProgressComponent);
        return _this;
    }
    IgrLinearProgress.prototype.createImplementation = function () {
        return new LinearProgress();
    };
    Object.defineProperty(IgrLinearProgress.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrLinearProgress.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrLinearProgress.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-linear-progress", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrLinearProgress.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrLinearProgress.prototype, "striped", {
        /**
         * Sets the striped look of the control.
        */
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            this.i.o = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrLinearProgress.prototype, "labelAlign", {
        /**
         * The position for the default label of the control.
        */
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = ensureEnum(LinearProgressLabelAlign_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrLinearProgress;
}(IgrProgressBase));
export { IgrLinearProgress };
